@@ -109,9 +109,22 @@ def process_field(field, value):
         field = field[: -len("__starts")]
 
     index = get_index_definition(field)
-    if index is None:
+    if "." in field:
+        # We came across a multifield
+        multifield = field
+        original_field = multifield.split(".")[0]
+        multifield_name = multifield.split(".")[1]
+        index = get_index_definition(original_field)
+        if "multifields" not in index:
+            return
+        _type = index["multifields"].get(multifield_name, {}).get("type")
+        if _type is None:
+            return
+        field = multifield
+    elif index:
+        _type = index["type"]
+    else:
         return
-    _type = index["type"]
     if not isinstance(value, list):
         value = [value]
         term_keyword = "term"
@@ -165,7 +178,10 @@ def process_field(field, value):
     elif modifier == "starts":
         value_to_search = f"{value}*"
         if value != "/":
-            value_to_search = f"{value}/*"
+            if value.endswith("/"):
+                value_to_search = f"{value}*"
+            else:
+                value_to_search = f"{value}/*"
         return match_type, {"wildcard": {field: value_to_search}}
     else:
         logger.warn(
@@ -194,7 +210,6 @@ def process_query_level(params):
 class Parser(BaseParser):
     def __call__(self, params: typing.Dict) -> ParsedQueryInfo:
         query_info = super().__call__(params)
-
         metadata = query_info.get("metadata", [])
         if metadata:
             search_data = SEARCH_DATA_FIELDS + metadata
